@@ -82,3 +82,30 @@ getarg()
       shift
    done
 }
+
+# extractline <manifestfile> <key>
+extractline()
+{
+	count=`wc -l < "$1"`
+	inkey=
+	value=
+	i=1
+	while (( $i <= $count ));
+	do
+		line="`head -n$i "$1" | tail -n1`"
+		if [ -n "$inkey" ]; then
+			if [ "${line:0:1}" == " " ]; then
+				value="$value${line:1}"
+			else
+				break
+			fi
+		else
+			if echo "$line" | grep "^$2:" > /dev/null; then
+				inkey=true
+				value="`sed 's/^[^:]*: *//' <<< $line`"
+			fi
+		fi
+		i=$(( $i + 1 ))
+	done
+	echo $value
+}
